@@ -108,7 +108,8 @@ if [ -e "$DWARFG_APAWEBROOT" ] ; then
 fi
 $APACHE_RELOAD || fail_nof "Apache reload command failed."
 # 2. Remove app data when NOT UPGRADING
-[ "$UPGRADING" -eq 0 ] && echo "Removing DB..." && echo "DROP DATABASE IF EXISTS \`$DWARFG_DBN\`;" | mysql $MYSQOPT
+echo "Removing DB..."
+[ "$UPGRADING" -eq 0 ] && echo "DROP DATABASE IF EXISTS \`$DWARFG_DBN\`;" | mysql $MYSQOPT
 # 3. Remove app itself, counting number of installations first
 NUM=$($C_LS -1 "${BASEDIR}"/"${SHORTNAME}"* | wc -l)
 echo "Removing $BINDIR ..." && [ -n "$BINDIR" ] && $C_RM -rf "$BINDIR" && RMV=$((RMV+1))
@@ -149,7 +150,7 @@ fi
 BACKUPS=0
 [ -d "$DWARFG_BACKUP" ] && BACKUPS=$($C_LS "$DWARFG_BACKUP" | $C_GREP -c "^")
 if [ "$NUM" -eq 1 ] ; then
-	if [[ 1 -eq "$KEEP_CACHE" || ( 0 -eq "$FORCE" && "$BACKUPS" -gt 0 ) || 1 -eq "$UPGRADING" ]] ; then
+	if [[ 1 -eq "$KEEP_CACHE" || ( 0 -eq "$FORCE" && "$BACKUPS" -gt 0 ) || 0 -eq "$UPGRADING" ]] ; then
 		echo "$NAME user and cache ($APPUSER and $DWARFG_CACHE) are kept as (keep_cache || (no_force && backups || upgrading))"
 	else
 		echo "Cleaning up last $NAME installation:"
