@@ -27,8 +27,8 @@ from datetime import datetime
 warnings.filterwarnings('ignore')
 
 appname="Dwarfguard SNMP Gateway"
-appversion="0.3.0"
-agent_version="1.1.0"
+appversion="0.4.0"
+agent_version="2.0.0"
 
 # knobs (defaults)
 # standalone variable below: True: ignore DB, get settings from cfgfile below
@@ -48,6 +48,7 @@ use_logfile = False
 single_action = 0
 dev_dbid = None
 dev_addr = None
+single_device = None
 sql_getcfg = "SELECT intval, strval FROM product_conf WHERE name = %s;"
 sql_get_list = "SELECT id, address, community_string, protocol_version, last_success, last_failure, errors_since_success, registered_as FROM snmp_devices;"
 sql_get_new = "SELECT id, address, community_string, protocol_version, errors_since_success, registered_as, devtoken_ag_copy, last_success FROM snmp_devices WHERE registered_as is NULL"
@@ -340,6 +341,7 @@ def get_snmp_machid(target):
 def print_help():
     print(appname, appversion, "is a SNMP Gateway that goes through the defined devices and reformats the data before sending it to the server.")
     print("\tIt basically substitutes a system agent for devices that are unable to run the agent but can provide some (limited) information over SNMP protocol.")
+    print("\tThis gateway reports itself to the server as SNMP agent version:", agent_version, ".")
     print("\tAt present, it supports getting some basic SNMP data from the Advantech router devices.")
     print("\nGateway supports (on top of single actions) a few modes:")
     print("\t(1) Running directly on the server machine as a system service (using systemd)")
@@ -359,6 +361,7 @@ def print_help():
     print("\t\t--standalone ... use everytime when running outside of application server")
     print("\t\t--daemon ... use for continuous run (must use superviser, gateway does NOT daemonize itself)")
     print("\t\t--oneshot ... perform one sweep over the SNMP devices and exit. Log is put on standard outpu unless --logfile option is used.")
+    print("\t\t--single_addr <IP/DNS address> ... work with only a single device with provided address. Useful to debug with --oneshot (NOT implied).")
     print("\t\t--interval <number> ... minimal number of seconds for one sweep (if continuous and cycle took less, sleep until interfal matched)")
     print("\t\t--snmp_timeout <number> ... wait <number> seconds for SNMP response")
     print("\t\t--snmp_retries <number> ... attempt <number> connections to a device until device considered failed")
@@ -430,7 +433,7 @@ def fwd_devdata_to_dg(device, logger):
                 device.delete = True
             else:
                 device.ok_push = False
-                talk("Non-ok app code from push: " +str(dwarfg_code) + " for device " +str(device_addr), logging.INFO, logger)
+                talk("Non-ok app code from push: " +str(dwarfg_code) + " for device " +str(device.addr), logging.INFO, logger)
         else:
             device.ok_push = False
             talk("Unexpected app code from push: " + str(dwarfg_code) + " for device " + str(device.addr), logging.NOTE, logger)
@@ -448,7 +451,7 @@ def read_devices(logger):
         # get new (to-be-registered) SNMP devices
         dbc.execute(sql_get_new)
         # device markers - SNMP, register, data pushed
-        new_devices = [manager.DEVICE(a[0], a[1], a[2], a[3], a[4], a[5], a[6], a[7] is not None) for a in dbc.fetchall() ]
+        new_devices = [manager.DEVICE(a[0], a[1], a[2], a[3], a[4], a[5], a[6], a[7] is not None) for a in dbc.fetchall() if single_device is None or a[1] == single_device ]
         matelib.mdb.commit()
         # get registered devices
         dbc.execute(sql_get_registered)
@@ -459,6 +462,7 @@ def read_devices(logger):
         old_devices_bad = []
         # split in two lists based on errors_since_success -> well-behaving and misbehaving
         for device in old_devices:
+            if single_device is not None and device[1] != single_device: continue
             if device[4] == 0:
                 old_devices_good.append(manager.DEVICE(device[0], device[1], device[2], device[3], device[4], device[5], device[6], device[7] is not None))
             else:
@@ -697,7 +701,7 @@ if __name__ == '__main__':
     signal.signal(signal.SIGHUP, dump_settings)
     # handle options - only once at startup
     try:
-        opts, args = getopt.getopt(sys.argv[1:], 'fhl', ['help', 'force', 'ssl', 'nossl', 'standalone', 'daemon', 'oneshot', 'snmp_timeout=', 'snmp_retries=', 'threads=', 'logfile=', 'interval=', 'loglevel=', 'add_device=', 'del_device=', 'list'])
+        opts, args = getopt.getopt(sys.argv[1:], 'fhl', ['help', 'force', 'ssl', 'nossl', 'standalone', 'daemon', 'oneshot', 'snmp_timeout=', 'snmp_retries=', 'threads=', 'logfile=', 'interval=', 'loglevel=', 'add_device=', 'del_device=', 'single_addr=', 'list'])
         for opt, arg, in opts:
             if opt == "-f" or opt == "--force":
                 os.remove(lockfile_fn)
@@ -732,6 +736,8 @@ if __name__ == '__main__':
             if opt == "--add_device":
                 dev_addr = str(arg)
                 single_action = 1
+            if opt == "--single_addr":
+                single_device = str(arg)
             if opt == "--del_device":
                 if arg.isnumeric():
                     dev_dbid = int(arg)
