@@ -289,7 +289,7 @@ class DatatableQueryBuilder
         $query = $qb->getQuery();
         $query->setHydrationMode(Query::HYDRATE_ARRAY)->useQueryCache($this->useQueryCache);
         //TODO Doctrine 3 error
-        //\call_user_func_array([$query, 'useResultCache'], $this->useResultCacheArgs);
+        \call_user_func_array([$query, 'useResultCache'], $this->useResultCacheArgs);
 
         return $query;
     }
@@ -308,7 +308,7 @@ class DatatableQueryBuilder
 
         $query = $qb->getQuery();
         $query->useQueryCache($this->useCountQueryCache);
-        //\call_user_func_array([$query, 'useResultCache'], $this->useCountResultCacheArgs);
+        \call_user_func_array([$query, 'useResultCache'], $this->useCountResultCacheArgs);
 
         return ! $qb->getDQLPart('groupBy')
             ? (int) $query->getSingleScalarResult()
