@@ -4,7 +4,6 @@ declare(strict_types=1);
 
 namespace App\Entity\Device;
 
-use Doctrine\DBAL\Types\Types;
 use Doctrine\ORM\Mapping as ORM;
 
 #[ORM\Table(name: 'device_custom_fields')]
@@ -14,7 +13,7 @@ class DeviceCustomField {
     /**
      * @var int|null
      */
-    #[ORM\Column(type: Types::INTEGER)]
+    #[ORM\Column(type: 'integer')]
     #[ORM\Id]
     #[ORM\GeneratedValue(strategy: 'AUTO')]
     private ?int $idDevice = null;
@@ -22,169 +21,169 @@ class DeviceCustomField {
     /**
      * @var int|null
      */
-    #[ORM\Column(name: 'num1', type: Types::INTEGER, nullable: true)]
+    #[ORM\Column(name: 'num1', type: 'integer', nullable: true)]
     public ?int $number1 = null;
 
     /**
      * @var int|null
      */
-    #[ORM\Column(name: 'num2', type: Types::INTEGER, nullable: true)]
+    #[ORM\Column(name: 'num2', type: 'integer', nullable: true)]
     public ?int $number2 = null;
 
     /**
      * @var int|null
      */
-    #[ORM\Column(name: 'num3', type: Types::INTEGER, nullable: true)]
+    #[ORM\Column(name: 'num3', type: 'integer', nullable: true)]
     public ?int $number3 = null;
 
     /**
      * @var int|null
      */
-    #[ORM\Column(name: 'num4', type: Types::INTEGER, nullable: true)]
+    #[ORM\Column(name: 'num4', type: 'integer', nullable: true)]
     public ?int $number4 = null;
 
     /**
      * @var int|null
      */
-    #[ORM\Column(name: 'num5', type: Types::INTEGER, nullable: true)]
+    #[ORM\Column(name: 'num5', type: 'integer', nullable: true)]
     public ?int $number5 = null;
 
     /**
      * @var int|null
      */
-    #[ORM\Column(name: 'num6', type: Types::INTEGER, nullable: true)]
+    #[ORM\Column(name: 'num6', type: 'integer', nullable: true)]
     public ?int $number6 = null;
 
     /**
      * @var int|null
      */
-    #[ORM\Column(name: 'num7', type: Types::INTEGER, nullable: true)]
+    #[ORM\Column(name: 'num7', type: 'integer', nullable: true)]
     public ?int $number7 = null;
 
     /**
      * @var int|null
      */
-    #[ORM\Column(name: 'num8', type: Types::INTEGER, nullable: true)]
+    #[ORM\Column(name: 'num8', type: 'integer', nullable: true)]
     public ?int $number8 = null;
 
     /**
      * @var int|null
      */
-    #[ORM\Column(name: 'num9', type: Types::INTEGER, nullable: true)]
+    #[ORM\Column(name: 'num9', type: 'integer', nullable: true)]
     public ?int $number9 = null;
 
     /**
      * @var string|null
      */
-    #[ORM\Column(name: 'txt1', type: Types::STRING, length: 1024, nullable: true)]
+    #[ORM\Column(name: 'txt1', type: 'string', length: 1024, nullable: true)]
     public ?string $text1 = null;
 
     /**
      * @var string|null
      */
-    #[ORM\Column(name: 'txt2', type: Types::STRING, length: 1024, nullable: true)]
+    #[ORM\Column(name: 'txt2', type: 'string', length: 1024, nullable: true)]
     public ?string $text2 = null;
 
     /**
      * @var string|null
      */
-    #[ORM\Column(name: 'txt3', type: Types::STRING, length: 1024, nullable: true)]
+    #[ORM\Column(name: 'txt3', type: 'string', length: 1024, nullable: true)]
     public ?string $text3 = null;
 
     /**
      * @var string|null
      */
-    #[ORM\Column(name: 'txt4', type: Types::STRING, length: 1024, nullable: true)]
+    #[ORM\Column(name: 'txt4', type: 'string', length: 1024, nullable: true)]
     public ?string $text4 = null;
 
     /**
      * @var string|null
      */
-    #[ORM\Column(name: 'txt5', type: Types::STRING, length: 1024, nullable: true)]
+    #[ORM\Column(name: 'txt5', type: 'string', length: 1024, nullable: true)]
     public ?string $text5 = null;
 
     /**
      * @var string|null
      */
-    #[ORM\Column(name: 'txt6', type: Types::STRING, length: 1024, nullable: true)]
+    #[ORM\Column(name: 'txt6', type: 'string', length: 1024, nullable: true)]
     public ?string $text6 = null;
 
     /**
      * @var string|null
      */
-    #[ORM\Column(name: 'txt7', type: Types::STRING, length: 1024, nullable: true)]
+    #[ORM\Column(name: 'txt7', type: 'string', length: 1024, nullable: true)]
     public ?string $text7 = null;
 
     /**
      * @var string|null
      */
-    #[ORM\Column(name: 'txt8', type: Types::STRING, length: 1024, nullable: true)]
+    #[ORM\Column(name: 'txt8', type: 'string', length: 1024, nullable: true)]
     public ?string $text8 = null;
 
     /**
      * @var string|null
      */
-    #[ORM\Column(name: 'txt9', type: Types::STRING, length: 1024, nullable: true)]
+    #[ORM\Column(name: 'txt9', type: 'string', length: 1024, nullable: true)]
     public ?string $text9 = null;
 
     /**
      * @var float|null
      */
-    #[ORM\Column(name: 'flo1', type: Types::FLOAT, nullable: true)]
+    #[ORM\Column(name: 'flo1', type: 'float', nullable: true)]
     public ?float $float1 = null;
 
     /**
      * @var float|null
      */
-    #[ORM\Column(name: 'flo2', type: Types::FLOAT, nullable: true)]
+    #[ORM\Column(name: 'flo2', type: 'float', nullable: true)]
     public ?float $float2 = null;
 
     /**
      * @var float|null
      */
-    #[ORM\Column(name: 'flo3', type: Types::FLOAT, nullable: true)]
+    #[ORM\Column(name: 'flo3', type: 'float', nullable: true)]
     public ?float $float3 = null;
 
     /**
      * @var float|null
      */
-    #[ORM\Column(name: 'flo4', type: Types::FLOAT, nullable: true)]
+    #[ORM\Column(name: 'flo4', type: 'float', nullable: true)]
     public ?float $float4 = null;
 
     /**
      * @var float|null
      */
-    #[ORM\Column(name: 'flo5', type: Types::FLOAT, nullable: true)]
+    #[ORM\Column(name: 'flo5', type: 'float', nullable: true)]
     public ?float $float5 = null;
 
     /**
      * @var float|null
      */
-    #[ORM\Column(name: 'flo6', type: Types::FLOAT, nullable: true)]
+    #[ORM\Column(name: 'flo6', type: 'float', nullable: true)]
     public ?float $float6 = null;
 
     /**
      * @var float|null
      */
-    #[ORM\Column(name: 'flo7', type: Types::FLOAT, nullable: true)]
+    #[ORM\Column(name: 'flo7', type: 'float', nullable: true)]
     public ?float $float7 = null;
 
     /**
      * @var float|null
      */
-    #[ORM\Column(name: 'flo8', type: Types::FLOAT, nullable: true)]
+    #[ORM\Column(name: 'flo8', type: 'float', nullable: true)]
     public ?float $float8 = null;
 
     /**
      * @var float|null
      */
-    #[ORM\Column(name: 'flo9', type: Types::FLOAT, nullable: true)]
+    #[ORM\Column(name: 'flo9', type: 'float', nullable: true)]
     public ?float $float9 = null;
 
     /**
      * @var \DateTime
      */
-    #[ORM\Column(name: 'last_update', type: Types::DATETIME_MUTABLE, options: ['default' => 'CURRENT_TIMESTAMP'])]
+    #[ORM\Column(name: 'last_update', type: 'datetime', options: ['default' => 'CURRENT_TIMESTAMP'])]
     public \DateTime $lastUpdate;
 
     /**
