@@ -6,7 +6,6 @@ namespace App\Entity\Device;
 
 use Doctrine\Common\Collections\ArrayCollection;
 use Doctrine\Common\Collections\Collection;
-use Doctrine\DBAL\Types\Types;
 use Doctrine\ORM\Mapping as ORM;
 
 #[ORM\Table(name: 'device_os_types')]
@@ -16,7 +15,7 @@ class DeviceOsType
     /**
      * @var int|null
      */
-    #[ORM\Column(type: Types::INTEGER)]
+    #[ORM\Column(type: 'integer')]
     #[ORM\Id]
     #[ORM\GeneratedValue(strategy: 'AUTO')]
     private ?int $id = null;
@@ -24,15 +23,9 @@ class DeviceOsType
     /**
      * @var string
      */
-    #[ORM\Column(type: Types::STRING, length: 64, unique: true, nullable: false)]
+    #[ORM\Column(type: 'string', length: 64, unique: true, nullable: false)]
     public string $name;
 
-	/**
-	 * @var string|null
-	 */
-	#[ORM\Column(type: Types::STRING, length: 64, unique: true, nullable: false)]
-	public ?string $directoryName = null;
-
     /**
      * @var DeviceType|null
      */
@@ -40,10 +33,16 @@ class DeviceOsType
     #[ORM\JoinColumn(name: 'dev_type')]
     public ?DeviceType $devType = null;
 
+    /**
+     * @var string
+     */
+    #[ORM\Column(type: 'string', length: 64, unique: true, nullable: false)]
+    public ?string $directoryName = null;
+
     /**
      * @var Collection
      */
-    #[ORM\OneToMany(targetEntity: DeviceOsVersion::class, mappedBy: 'osType', cascade: ['persist'])]
+    #[ORM\OneToMany(mappedBy: 'osType', targetEntity: DeviceOsVersion::class, cascade: ['persist'])]
     #[ORM\JoinColumn(name: 'id')]
     public Collection $osVersions;
 
