@@ -7,7 +7,6 @@ namespace App\Entity\Device;
 use App\Entity\Device;
 use Doctrine\Common\Collections\ArrayCollection;
 use Doctrine\Common\Collections\Collection;
-use Doctrine\DBAL\Types\Types;
 use Doctrine\ORM\Mapping as ORM;
 
 #[ORM\Table(name: 'device_sync_statuses')]
@@ -20,7 +19,7 @@ class DeviceSyncStatus
     /**
      * @var int|null
      */
-    #[ORM\Column(type: Types::INTEGER)]
+    #[ORM\Column(type: 'integer')]
     #[ORM\Id]
     #[ORM\GeneratedValue(strategy: 'AUTO')]
     private ?int $id = null;
@@ -28,7 +27,7 @@ class DeviceSyncStatus
     /**
      * @var string
      */
-    #[ORM\Column(type: Types::STRING, length: 64, unique: true, nullable: false)]
+    #[ORM\Column(type: 'string', length: 64, unique: true, nullable: false)]
     public string $description;
 
     /**
