@@ -4,7 +4,6 @@ declare(strict_types=1);
 
 namespace App\Entity\Device;
 
-use Doctrine\DBAL\Types\Types;
 use Doctrine\ORM\Mapping as ORM;
 
 #[ORM\Table(name: 'device_user_modules')]
@@ -14,7 +13,7 @@ class DeviceUserModule
     /**
      * @var int|null
      */
-    #[ORM\Column(type: Types::INTEGER)]
+    #[ORM\Column(type: 'integer')]
     #[ORM\Id]
     #[ORM\GeneratedValue(strategy: 'AUTO')]
     private ?int $id = null;
