@@ -6,7 +6,6 @@ namespace App\Entity\Label;
 
 use Doctrine\Common\Collections\ArrayCollection;
 use Doctrine\Common\Collections\Collection;
-use Doctrine\DBAL\Types\Types;
 use Doctrine\ORM\Mapping as ORM;
 
 #[ORM\Table(name: 'labels')]
@@ -16,7 +15,7 @@ class Label
     /**
      * @var int|null
      */
-    #[ORM\Column(type: Types::INTEGER)]
+    #[ORM\Column(type: 'integer')]
     #[ORM\Id]
     #[ORM\GeneratedValue(strategy: 'AUTO')]
     private ?int $id = null;
@@ -24,13 +23,13 @@ class Label
     /**
      * @var string
      */
-    #[ORM\Column(type: Types::STRING, length: 64, unique: true, nullable: false, options: ['datatable_editable' => true])]
+    #[ORM\Column(type: 'string', length: 64, unique: true, nullable: false)]
     public string $label;
 
     /**
      * @var Collection
      */
-    #[ORM\OneToMany(targetEntity: LabelDeviceMap::class, mappedBy: 'label', cascade: ['persist', 'remove'])]
+    #[ORM\OneToMany(mappedBy: 'label', targetEntity: LabelDeviceMap::class, cascade: ['persist', 'remove'])]
     #[ORM\JoinColumn(name: 'id')]
     public Collection $devices;
 
