@@ -7,7 +7,6 @@ namespace App\Entity\MonitoringGroup;
 use App\Entity\Alert\Alert;
 use Doctrine\Common\Collections\ArrayCollection;
 use Doctrine\Common\Collections\Collection;
-use Doctrine\DBAL\Types\Types;
 use Doctrine\ORM\Mapping as ORM;
 
 #[ORM\Table(name: 'monitoring_groups')]
@@ -17,7 +16,7 @@ class MonitoringGroup
     /**
      * @var int|null
      */
-    #[ORM\Column(type: Types::INTEGER)]
+    #[ORM\Column(type: 'integer')]
     #[ORM\Id]
     #[ORM\GeneratedValue(strategy: 'AUTO')]
     private ?int $id = null;
@@ -25,20 +24,20 @@ class MonitoringGroup
     /**
      * @var string
      */
-    #[ORM\Column(type: Types::STRING, length: 64, nullable: false, options: ['datatable_editable' => true])]
+    #[ORM\Column(type: 'string', length: 64, nullable: false)]
     public string $name;
 
     /**
      * @var Collection
      */
-    #[ORM\OneToMany(targetEntity: MonitoringGroupMapping::class, mappedBy: 'monitoringGroup', cascade: ['persist', 'remove'])]
+    #[ORM\OneToMany(mappedBy: 'monitoringGroup', targetEntity: MonitoringGroupMapping::class, cascade: ['persist', 'remove'])]
     #[ORM\JoinColumn(name: 'id')]
     public Collection $monitoringGroupMappings;
 
     /**
      * @var Collection
      */
-    #[ORM\OneToMany(targetEntity: Alert::class, mappedBy: 'targetMonitoringGroup', cascade: ['persist'])]
+    #[ORM\OneToMany(mappedBy: 'targetMonitoringGroup', targetEntity: Alert::class, cascade: ['persist'])]
     #[ORM\JoinColumn(name: 'id')]
     public Collection $alerts;
 
@@ -70,9 +69,9 @@ class MonitoringGroup
 
     }
 
-	/**
-	 * @return ArrayCollection
-	 */
+    /**
+     * @return ArrayCollection
+     */
     public function getMonitoringGroupMappings(): ArrayCollection {
 
         return $this->monitoringGroupMappings;
@@ -80,7 +79,7 @@ class MonitoringGroup
     }
 
     /**
-     * @return Collection<int, Alert>
+     * @return ArrayCollection
      */
     public function getAlerts(): ArrayCollection {
 
