@@ -4,7 +4,6 @@ declare(strict_types=1);
 
 namespace App\Entity\Product;
 
-use Doctrine\DBAL\Types\Types;
 use Doctrine\ORM\Mapping as ORM;
 
 #[ORM\Table(name: 'product_flags')]
@@ -14,20 +13,20 @@ class ProductFlags
     /**
      * @var string
      */
-    #[ORM\Column(type: Types::STRING)]
+    #[ORM\Column(type: 'string')]
     #[ORM\Id]
     private readonly string $id;
 
     /**
      * @var int
      */
-    #[ORM\Column(type: Types::INTEGER, nullable: false)]
+    #[ORM\Column(type: 'integer', nullable: false)]
     public int $version;
 
     /**
      * @var string
      */
-    #[ORM\Column(name: 'description', type: Types::TEXT, nullable: true, options: ['default' => null])]
+    #[ORM\Column(name: 'description', type: 'text', nullable: true, options: ['default' => null])]
     public ?string $description = null;
 
     /**
